# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.6] - 2026-04-02

### Changed
- implement alarm fixes and documentation updates
- Fixing link to appendix file

## [1.0.5] - 2026-03-03

### Changed
- MSK, OpenSearch, EMR, ApiGatewayV2, Grafana OSS support, UX enhancements, dependency bumps
- Adding past CHANGELOG and updating auto_release workflow

## [1.0.4] - 2026-02-16

### Added
- Add update-workload command for modifying existing workload configurations
- Bulk and range selection support for alarm discovery

## [1.0.3] - 2026-01-26

### Added
- Support for Lambda@Edge alarm creation
- CONDITIONAL metric validation for alarm creation
- Issue templates to the repository
- Secret scanning GitHub action

### Changed
- Updated documentation for alarm creation
- Updated Slack notifications workflow configuration

### Fixed
- Fixed link in CloudWatch Alarm Creation documentation

## [1.0.2] - 2026-01-05

### Added
- Route53 HealthCheckStatus alarm support
- EndpointUnhealthyENICount alarm support

### Changed
- Updated APM EventBridge regex patterns

## [1.0.1] - 2025-12-15

### Added
- Initial release of IDR CLI

### Fixed
- Support Case CTI handling
- ALB alarm definitions
- Documentation updates and formatting improvements

## [1.0.0] - 2025-11-17

### Added
- Initial release of AWS IDR Customer CLI
